@@ -11,7 +11,7 @@
    Class declaration for a sample output driver with no additional attributes
    and methods (minimal interface)
 
-   Copyright (C) 1993,1994,1995,1996,1997,1998 Wolfgang Glunz, wglunz@geocities.com
+   Copyright (C) 1993 - 2001 Wolfgang Glunz, wglunz@pstoedit.net
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -41,7 +41,11 @@ public:
 	~drvRPL(); // Destructor
 
 #include "drvfuncs.h"
+private:
+	void print_coords();
 
 };
 
 #endif
+ 
+ 
